{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "dundas-bi.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "dundas-bi.fullname" -}}
{{- if .Values.fullnameOverride }}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- $name := default .Chart.Name .Values.nameOverride }}
{{- if contains $name .Release.Name }}
{{- .Release.Name | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" }}
{{- end }}
{{- end }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "dundas-bi.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "dundas-bi.labels" -}}
helm.sh/chart: {{ include "dundas-bi.chart" . }}
{{ include "dundas-bi.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "dundas-bi.selectorLabels" -}}
app.kubernetes.io/name: {{ include "dundas-bi.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- end }}

{{/*
Create the name of the service account to use
*/}}
{{- define "dundas-bi.serviceAccountName" -}}
{{- if .Values.serviceAccount.create }}
{{- default (include "dundas-bi.fullname" .) .Values.serviceAccount.name }}
{{- else }}
{{- default "default" .Values.serviceAccount.name }}
{{- end }}
{{- end }}


{{/* 
Create Global Dundas BI Application Database Connection String Properties 
*/}}

{{- define "dundas.bi.appDb.appDbConnString" -}}
{{- if ( include "global.dundas.bi.appDb.appDbConnString" . ) }}
  {{- ( include "global.dundas.bi.appDb.appDbConnString" . ) -}}
{{- else if .Values.dundas.bi.appDb.appDbConnString -}}
  {{- .Values.dundas.bi.appDb.appDbConnString -}}
{{- else -}}
  {{- "placeholder" -}}
{{- end -}}
{{- end -}}
            
{{- define "dundas.bi.appDb.warehouseDbConnString" -}}
{{- if ( include "global.dundas.bi.appDb.warehouseDbConnString" . ) }}
  {{- ( include "global.dundas.bi.appDb.warehouseDbConnString" . ) -}}
{{- else if .Values.dundas.bi.appDb.warehouseDbConnString -}}
  {{- .Values.dundas.bi.appDb.warehouseDbConnString -}}
{{- else -}}
  {{- "" -}}
{{- end -}}
{{- end -}}

{{- define "dundas.bi.appDb.useExistingSecretForAppDbConnString" -}}
{{- if eq (include "global.dundas.bi.appDb.useExistingSecretForAppDbConnString" .) "true" }}
  {{- ( include "global.dundas.bi.appDb.useExistingSecretForAppDbConnString" . ) -}}
{{- else if .Values.dundas.bi.appDb.useExistingSecretForAppDbConnString -}}
  {{- .Values.dundas.bi.appDb.useExistingSecretForAppDbConnString -}}
{{- else -}}
  {{- false -}}
{{- end -}}
{{- end -}}

{{- define "dundas.bi.appDb.useExistingSecretForWarehouseDbConnString" -}}
{{- if eq ( include "global.dundas.bi.appDb.useExistingSecretForWarehouseDbConnString" . ) "true" }}
  {{- ( include "global.dundas.bi.appDb.useExistingSecretForWarehouseDbConnString" . ) -}}
{{- else if .Values.dundas.bi.appDb.useExistingSecretForWarehouseDbConnString -}}
  {{- .Values.dundas.bi.appDb.useExistingSecretForWarehouseDbConnString -}}
{{- else -}}
  {{- false -}}
{{- end -}}
{{- end -}}

{{- define "dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName" -}}
{{- if (include "global.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName" . ) }}
  {{- (include "global.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName" . ) -}}
{{- else if .Values.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName -}}
  {{- .Values.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName -}}
{{- else -}}
  {{- "" -}}
{{- end -}}
{{- end -}}

{{- define "dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey" -}}
{{- if (include "global.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey" . ) }}
  {{- (include "global.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey" . ) -}}
{{- else if .Values.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey -}}
  {{- .Values.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey -}}
{{- else -}}
  {{- "" -}}
{{- end -}}
{{- end -}}

{{- define "dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretName" -}}
{{- if ( include "global.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretName" . ) }}
  {{- ( include "global.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretName" . ) -}}
{{- else if .Values.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretName -}}
  {{- .Values.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretName -}}
{{- else -}}
  {{- "" -}}
{{- end -}}
{{- end -}}

{{- define "dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretKey" -}}
{{- if (include "global.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretKey" . ) }}
  {{- (include "global.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretKey" . ) -}}
{{- else if .Values.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretKey -}}
  {{- .Values.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretKey -}}
{{- else -}}
  {{- "" -}}
{{- end -}}
{{- end -}}

{{- define "dundas.bi.appDb.appStorage" -}}
{{- if ( include "global.dundas.bi.appDb.appStorage" . ) }}
  {{- ( include "global.dundas.bi.appDb.appStorage" . ) -}}
{{- else if .Values.dundas.bi.appDb.appStorage -}}
  {{- .Values.dundas.bi.appDb.appStorage -}}
{{- else -}}
  {{- "SqlServer" -}}
{{- end -}}
{{- end -}}



{{- define "dundas.bi.appDb.appDbCreatorConnString" -}}
{{- if ( include "global.dundas.bi.appDb.appDbCreatorConnString" . ) }}
  {{- ( include "global.dundas.bi.appDb.appDbCreatorConnString" . ) -}}
{{- else if .Values.dundas.bi.appDb.appDbCreatorConnString -}}
  {{- .Values.dundas.bi.appDb.appDbCreatorConnString -}}
{{- else -}}
  {{- "" -}}
{{- end -}}
{{- end -}}
        
{{- define "dundas.bi.appDb.whDbCreatorConnString" -}}
{{- if ( include "global.dundas.bi.appDb.whDbCreatorConnString" . ) }}
  {{- ( include "global.dundas.bi.appDb.whDbCreatorConnString" . ) -}}
{{- else if .Values.dundas.bi.appDb.whDbCreatorConnString -}}
  {{- .Values.dundas.bi.appDb.whDbCreatorConnString -}}
{{- else -}}
  {{- "" -}}
{{- end -}}
{{- end -}}

{{- define "dundas.bi.appDb.useExistingSecretForAppDbCreatorConnectionString" -}}
{{- if eq ( include "global.dundas.bi.appDb.useExistingSecretForAppDbCreatorConnectionString" . ) "true" }}
  {{- ( include "global.dundas.bi.appDb.useExistingSecretForAppDbCreatorConnectionString" . ) -}}
{{- else if .Values.dundas.bi.appDb.useExistingSecretForAppDbCreatorConnectionString -}}
  {{- .Values.dundas.bi.appDb.useExistingSecretForAppDbCreatorConnectionString -}}
{{- else -}}
  {{- false -}}
{{- end -}}
{{- end }}

{{- define "dundas.bi.appDb.useExistingSecretForWarehouseDbCreatorConnectionString" -}}
{{- if eq ( include "global.dundas.bi.appDb.useExistingSecretForWhDbCreatorConnectionString" . ) "true" }}
  {{- ( include "global.dundas.bi.appDb.useExistingSecretForWhDbCreatorConnectionString" . ) -}}
{{- else if .Values.dundas.bi.appDb.useExistingSecretForWhDbCreatorConnectionString -}}
  {{- .Values.dundas.bi.appDb.useExistingSecretForWhDbCreatorConnectionString -}}
{{- else -}}
  {{- false -}}
{{- end -}}
{{- end }}

{{- define "dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretName" -}}
{{- if ( include "global.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretName" . ) }}
  {{- ( include "global.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretName" . ) -}}
{{- else if .Values.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretName -}}
  {{- .Values.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretName -}}
{{- else -}}
  {{- "" -}}
{{- end -}}
{{- end }}

{{- define "dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretKey" -}}
{{- if ( include "global.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretKey" . ) }}
  {{- ( include "global.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretKey" . ) -}}
{{- else if .Values.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretKey -}}
  {{- .Values.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretKey -}}
{{- else -}}
  {{- "" -}}
{{- end -}}
{{- end }}

{{- define "dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretName" -}}
{{- if ( include "global.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretName" . ) }}
  {{- ( include "global.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretName" . ) -}}
{{- else if .Values.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretName -}}
  {{- .Values.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretName -}}
{{- else -}}
  {{- "" -}}
{{- end -}}
{{- end }}

{{- define "dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretKey" -}}
{{- if ( include "global.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretKey" . ) }}
  {{- .Values.global.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretKey -}}
{{- else if .Values.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretKey -}}
  {{- .Values.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretKey -}}
{{- else -}}
  {{- "" -}}
{{- end -}}
{{- end }}

{{/*
  DUNDAS_BI_APP_STORAGE Environment Variable
*/}}

{{- define "dundas.env.appStorage" -}}
 
{{- $postgresEnabled := false }}
{{- if .Values.global }}
{{- if .Values.global.postgresql }}
{{- if .Values.global.postgresql.enabled }}
{{- $postgresEnabled = true }}
{{- end }}  
{{- end }}
{{- end }}  
- name: DUNDAS_BI_APP_STORAGE
{{ if or .Values.dundas.bi.appDb.express $postgresEnabled }}
  value: Postgres
{{ else }}
  value: {{ include "dundas.bi.appDb.appStorage" . }}
{{ end }}

{{- end -}}

{{/*
  DUNDAS_BI_APP_DB_CONN_STRING Environment Variable
*/}}
{{- define "dundas.env.dundasBiAppDbConnString" -}}

{{ if .Values.dundas.bi.appDb.express }}
- name: DUNDAS_BI_APP_DB_CONN_STRING
  value: "Host={{ .Release.Name }}-dundas-bi-database; Database=Dundas BI {{ .Release.Name }}; Username=postgres;Password=$(POSTGRES_PASSWORD)"
{{ else }}
- name: DUNDAS_BI_APP_DB_CONN_STRING
  valueFrom:
  {{ if eq (include "dundas.bi.appDb.useExistingSecretForAppDbConnString" .) "true" }}
    secretKeyRef:
      name:  {{ include "dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName" . }}
      key: {{ include "dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey" . }}
  {{ else }}
    secretKeyRef:
      name: {{ .Release.Name }}
      key: DBI_CONNECTION_STRING
    {{ end }}
{{ end }}

{{- end -}}


{{/*
  DUNDAS_BI_WAREHOUSE_DB_CONN_STRING Environment Variable
*/}}
{{- define "dundas.env.dundasBiWhDbConnString" -}}

{{- $postgresEnabled := false }}
{{- if .Values.global }}
{{- if .Values.global.postgresql }}
{{- if .Values.global.postgresql.enabled }}
{{- $postgresEnabled = true }}
{{- end }}  
{{- end }}
{{- end }}  

# Warehouse connection string section 
{{ if .Values.dundas.bi.appDb.express }}
# Do nothing express 
{{ else }}

{{ if eq ( include "dundas.bi.appDb.useExistingSecretForWarehouseDbConnString" . ) "true" }}
- name: DUNDAS_BI_WAREHOUSE_DB_CONN_STRING
  valueFrom:
    secretKeyRef:
      name:  {{ include "dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretName" . }}
      key: {{ include "dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretKey" . }}    
{{ else if ( include "dundas.bi.appDb.warehouseDbConnString" . ) }}
- name: DUNDAS_BI_WAREHOUSE_DB_CONN_STRING
  valueFrom:
    secretKeyRef:
      name: {{ .Release.Name }}
      key: DBI_WAREHOUSE_CONNECTION_STRING
{{ end }}

# End Warehouse connection string section 
{{- end -}}

{{- end -}}

{{/*
  DUNDAS_BI_DB_CREATOR_APP_DB_CONNECTION_STRING Environment Variable
*/}}
{{- define "dundas.env.dundasBiAppDbCreatorConnString" -}}

{{- $postgresEnabled := false }}
{{- if .Values.global }}
{{- if .Values.global.postgresql }}
{{- if .Values.global.postgresql.enabled }}
{{- $postgresEnabled = true }}
{{- end }}  
{{- end }}
{{- end }}  

{{- if not .Values.dundas.bi.appDb.express }}

{{- if eq ( include "dundas.bi.appDb.useExistingSecretForAppDbCreatorConnectionString" . ) "true" }}
- name: DUNDAS_BI_DB_CREATOR_APP_DB_CONNECTION_STRING
  valueFrom:
    secretKeyRef:
      name: {{ include "dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretName" . }}
      key: {{ include "dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretKey" . }}
{{- else if ne (include "dundas.bi.appDb.appDbCreatorConnString" .) "" }}
- name: DUNDAS_BI_DB_CREATOR_APP_DB_CONNECTION_STRING
  valueFrom:
    secretKeyRef:
      name: {{ .Release.Name }}
      key: DBI_CREATOR_CONNECTION_STRING
{{- else if $postgresEnabled }}
- name: DUNDAS_BI_DB_CREATOR_APP_DB_CONNECTION_STRING
  valueFrom:
    secretKeyRef:
      name: {{ .Release.Name }}
      key: DBI_CREATOR_CONNECTION_STRING
{{- end }}

{{- end }}
{{- end -}}

{{/*
  DBI_WAREHOUSE_CREATOR_CONNECTION_STRING Environment Variable
*/}}
{{- define "dundas.env.dundasBiWarehouseDbCreatorConnString" -}}


{{- $postgresEnabled := false }}
{{- if .Values.global }}
{{- if .Values.global.postgresql }}
{{- if .Values.global.postgresql.enabled }}
{{- $postgresEnabled = true }}
{{- end }}  
{{- end }}
{{- end }}  

{{- if not .Values.dundas.bi.appDb.express }}

{{- if eq ( include "dundas.bi.appDb.useExistingSecretForWarehouseDbCreatorConnectionString" . ) "true" }}
- name: DUNDAS_BI_DB_CREATOR_WH_DB_CONNECTION_STRING
  valueFrom:
    secretKeyRef:
      name: {{ include "dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretName" . }}
      key: {{ include "dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretKey" . }}
{{- else if ne (include "dundas.bi.appDb.whDbCreatorConnString" .) "" }}
- name: DUNDAS_BI_DB_CREATOR_WH_DB_CONNECTION_STRING
  valueFrom:
    secretKeyRef:
      name: {{ .Release.Name }}
      key: DBI_WAREHOUSE_CREATOR_CONNECTION_STRING
{{- else if $postgresEnabled }}
- name: DUNDAS_BI_DB_CREATOR_WH_DB_CONNECTION_STRING
  valueFrom:
    secretKeyRef:
      name: {{ .Release.Name }}
      key: DBI_WAREHOUSE_CREATOR_CONNECTION_STRING
{{- end }}

{{- end }}
{{- end -}}

{{/*
  DUNDAS_BI_DEPLOYMENT_MODE Environment Variable
*/}}
{{- define "dundas.env.deploymentMode" -}}
{{ if .Values.dundas.bi.deploymentMode }}
- name: DUNDAS_BI_DEPLOYMENT_MODE 
  value: "{{ .Values.dundas.bi.deploymentMode }}"
{{ end }}
{{- end -}}

{{/*
  DUNDAS_BI_STARTUP_COMMAND Environment Variable
*/}}
{{- define "dundas.env.startCommand" -}}
{{ if .Values.dundas.bi.startCommand }}
- name: DUNDAS_BI_STARTUP_COMMAND
  value: "{{ .Values.dundas.bi.startCommand }}"
{{ end }}
{{- end -}}

{{/*
  DUNDAS_BI_EXTERNAL_APPLICATION_URL Environment Variable
*/}}
{{- define "dundas.env.externalApplicationUrl" -}}
{{ if .Values.ingress.enabled }}
{{- if not .Values.dundas.bi.externalApplicationUrl  }}
{{- range $host := .Values.ingress.hosts }}
{{- range .paths }}
- name: DUNDAS_BI_EXTERNAL_APPLICATION_URL
  value: http{{ if $.Values.ingress.tls }}s{{ end }}://{{ $host.host }}{{ . }}{{ $.Values.dundas.bi.virtualDirectoryPath | trimPrefix "/" }}
{{- end }}
{{- end }}
{{- end }}
{{ end }} 
{{ if .Values.dundas.bi.externalApplicationUrl }}
- name: DUNDAS_BI_EXTERNAL_APPLICATION_URL
  value: "{{ .Values.dundas.bi.externalApplicationUrl }}"
{{ end }}
{{- end -}}

{{/*
  DUNDAS_BI_INTERNAL_APPLICATION_URL Environment Variable 
*/}}
{{- define "dundas.env.internalApplicationUrl" -}}  
{{ if .Values.dundas.bi.internalApplicationUrl }}
- name: DUNDAS_BI_INTERNAL_APPLICATION_URL
  value: "{{ .Values.dundas.bi.internalApplicationUrl }}"
{{ else }}
- name: DUNDAS_BI_INTERNAL_APPLICATION_URL
  value: "http://{{ .Release.Name }}-dundas-bi-website{{ if ne .Release.Namespace "default" }}.{{ .Release.Namespace }}{{- end -}}:{{ .Values.dundas.bi.website.port }}/"      
{{ end }} 

{{- end -}}

{{/*
  Setup Image
*/}}
{{- define "dundas.env.setupimage" -}}
{{ if .Values.dundas.bi.setup.image.override.enabled }}{{ .Values.dundas.bi.setup.image.override.name }}{{ else }}{{ include "dundas.bi.defaultImageRepository" . }}/dundas-bi-setup:{{ .Values.dundas.bi.version }}{{ end }}   
{{- end -}}

{{/*
  Init Container - wait-for-dundasbi-website
*/}}
{{- define "dundas.initcontainer.waitForDundasBiWebsite" -}}
# Wait for Dundas BI 
- name: wait-for-dundasbi-website
  image: {{ include "dundas.env.setupimage" . | quote }}
  command: ['sh', '-c', "/usr/share/dotnet/dotnet /usr/share/dundas/bi/deployment/noversion/DeploymentConsole.dll --container --nonroot || echo 'done'" ]
  imagePullPolicy: {{ include "imagePullPolicy" . }}
  securityContext:
    {{- toYaml .Values.securityContext | nindent 12 }}
  resources:
     {{- toYaml .Values.dundas.bi.setup.resources | nindent 12 }}
  env:
    - name: A180BB4E4AE416297A0AAC7FACFCB751
      value: "ScheduleWait"
    - name: DUNDAS_BI_INTERNAL_APPLICATION_URL
      value: "http://{{ .Release.Name }}-dundas-bi-website{{ if ne .Release.Namespace "default" }}.{{ .Release.Namespace }}{{- end -}}:{{ .Values.dundas.bi.website.port }}/"
	  
{{- end -}}

{{- define "dundas.initcontainer.commonDbiConfigInit" -}}
# Common DBI Config Init
- name: dbi-config-init
  image: {{ include "dundas.env.setupimage" . | quote }}
  command: ['sh', '-c', "/usr/share/dotnet/dotnet /usr/share/dundas/bi/deployment/noversion/DeploymentConsole.dll --container --nonroot || echo 'done'" ]
  imagePullPolicy: {{ include "imagePullPolicy" . }}
  securityContext:
    {{- toYaml .Values.securityContext | nindent 4 }}
  resources:
    {{- toYaml .Values.dundas.bi.setup.resources | nindent 4 }}
  volumeMounts:    
    - name: dundasshare
      mountPath: /dundas-bi-share/
{{- end -}}

{{/*
  Init Container - storage DBI Config init
*/}}
{{- define "dundas.initcontainer.storageDbiConfigInit" -}}
{{ include "dundas.initcontainer.commonDbiConfigInit" . }}
  env:
    {{ include "dundas.initcontainer.env.commonDbiConfigInit" . }}
    - name: DUNDAS_BI_CONFIG_FILE_PATH
      value: "/usr/share/dundas/bi/Files/Container/www/BIWebStorage/App_Data/dbi.config"
{{- end -}}

{{/*
  Init Container - GatewayHub DBI Config init
*/}}
{{- define "dundas.initcontainer.gatewayhubDbiConfigInit" -}}
{{ include "dundas.initcontainer.commonDbiConfigInit" . }}
  env:
    {{ include "dundas.initcontainer.env.commonDbiConfigInit" . }}
    - name: DUNDAS_BI_CONFIG_FILE_PATH
      value: "/usr/share/dundas/bi/Files/Container/www/BIGatewayHub/App_Data/dbi.config"
{{- end -}}

{{- define "dundas.initcontainer.authbridgeDbiConfigInit" -}}
{{ include "dundas.initcontainer.commonDbiConfigInit" . }}
  env:
    {{ include "dundas.initcontainer.env.commonDbiConfigInit" .   }}
    - name: DUNDAS_BI_CONFIG_FILE_PATH
      value: "/usr/share/dundas/bi/Files/Container/www/BIWebsite/App_Data/dbi.config"
{{- end -}}

{{- define "dundas.initcontainer.env.commonDbiConfigInit" -}}

    # Common DBI Config Env
    - name: CHECK_FOR_ACTION
      value: "DbiConfig"
    {{ if .Values.dundas.bi.appDb.express }}
    - name: POSTGRES_PASSWORD
      valueFrom:
        secretKeyRef:
          name: {{ .Release.Name }}
          key: postgres-password
    {{ end }}
    {{- include "dundas.env.dundasBiAppDbConnString" . | indent 4 }}
	{{- include "dundas.env.appStorage" . | indent 4 }}
	{{- include "dundas.env.deploymentMode" . | indent 4 }}
{{- end -}}

{{- define "dundas.env.adminpassword" -}}
{{ if ne ( include "logi.symphony.auth.existingSecret" .) ""  }}
  {{ if .Values.dundas.bi.password.setAdminPassword }}
- name: DUNDAS_BI_ADMIN_PASSWORD
  valueFrom: 
    secretKeyRef:
      name: {{ include "logi.symphony.auth.existingSecret" . }}
      key: {{ include "logi.symphony.auth.secretKeys.adminPasswordKey" . }}
  {{ end }}
{{ else if ( include "logi.symphony.auth.adminPassword" . ) }}
  {{ if .Values.dundas.bi.password.setAdminPassword }}
- name: DUNDAS_BI_ADMIN_PASSWORD
  valueFrom:
    secretKeyRef:
      name: {{ .Release.Name }}
      key: dundas-bi-admin-password 
  {{ end }}
{{ else }}
  {{ if or (.Values.dundas.bi.appDb.express) (.Values.dundas.bi.password.setAdminPassword) }}
- name: DUNDAS_BI_ADMIN_PASSWORD
    {{ if .Values.dundas.bi.password.generateRandomPassword }}
  valueFrom:
    secretKeyRef:
      name: {{ .Release.Name }}
      key: dundas-bi-admin-password 
    {{ else if .Values.dundas.bi.password.useExistingSecretForAdminPassword }}
  valueFrom:
    secretKeyRef:
      name: {{ .Values.dundas.bi.password.secretKeyRef.adminPasswordSecretName }}
      key: {{ .Values.dundas.bi.password.secretKeyRef.adminPasswordSecretKey }}
    {{ else }}
  valueFrom:
    secretKeyRef:
      name: {{ .Release.Name }}
      key: dundas-bi-admin-password 
     {{ end }}                  
  {{ end }}
{{ end }}
{{- end -}}

{{- define "logi.symphony.auth.secretKeys.adminPasswordKey" -}}
{{- if .Values.global -}}
  {{- if .Values.global.logi -}}
    {{- if .Values.global.logi.symphony -}}
      {{- if .Values.global.logi.symphony.auth -}}
        {{- if .Values.global.logi.symphony.auth.secretKeys -}}
	      {{- if .Values.global.logi.symphony.auth.secretKeys.adminPasswordKey -}}
		    {{ ".Values.global.logi.symphony.auth.secretKeys.adminPasswordKey" }}
		  {{- else -}}
		  {{ "" }}
		  {{- end -}}
        {{- else -}}
        {{ "" }}
        {{- end -}}
      {{- else -}}
	  {{ "" }}
      {{- end -}}
	
    {{- else -}}
    {{ "" }}
    {{- end -}}
	
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "logi.symphony.auth.existingSecret" -}}
{{- if .Values.global -}}
  {{- if .Values.global.logi -}}
    {{- if .Values.global.logi.symphony -}}
      {{- if .Values.global.logi.symphony.auth -}}
        {{- if .Values.global.logi.symphony.auth.existingSecret -}}
		  {{ .Values.global.logi.symphony.auth.existingSecret }}
		{{- else -}}
		  {{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}



{{- define "logi.symphony.auth.adminPassword" -}}
  {{- if .Values.global -}}
    {{- if .Values.global.logi -}}
	  {{- if .Values.global.logi.symphony -}}
	    {{- if .Values.global.logi.symphony.auth -}}
		  {{- if .Values.global.logi.symphony.auth.adminPassword -}}
		    {{ .Values.global.logi.symphony.auth.adminPassword }}
		  {{- else -}}
		    {{ "" }}
		  {{- end -}}
		{{- else -}}
		  {{ "" }}
		{{- end -}}
	  {{- else -}}
	    {{ "" }}
	  {{- end -}}
	{{- else -}}
	  {{ "" }}
	{{- end -}}
  {{- else -}}
    {{ "" }}
  {{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.appStorage" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.appStorage -}}
		{{ .Values.global.dundas.bi.appDb.appStorage }}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.appDbConnString" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.appDbConnString -}}
		{{ .Values.global.dundas.bi.appDb.appDbConnString }}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.warehouseDbConnString" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.warehouseDbConnString -}}
		{{ .Values.global.dundas.bi.appDb.warehouseDbConnString }}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.useExistingSecretForAppDbConnString" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.useExistingSecretForAppDbConnString -}}
		{{ .Values.global.dundas.bi.appDb.useExistingSecretForAppDbConnString }}
		{{- else -}}
		{{ false }}
		{{- end -}}
      {{- else -}}
      {{ false }}
      {{- end -}}
    {{- else -}}
	{{ false }}
    {{- end -}}
  {{- else -}}
  {{ false }}
  {{- end -}}
{{- else -}}
{{ false }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.useExistingSecretForWarehouseDbConnString" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.useExistingSecretForWarehouseDbConnString -}}
		{{ .Values.global.dundas.bi.appDb.useExistingSecretForWarehouseDbConnString }}
		{{- else -}}
		{{ false }}
		{{- end -}}
      {{- else -}}
      {{ false }}
      {{- end -}}
    {{- else -}}
	{{ false }}
    {{- end -}}
  {{- else -}}
  {{ false }}
  {{- end -}}
{{- else -}}
{{ false }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.appDbCreatorConnString" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.appDbCreatorConnString -}}
		{{ .Values.global.dundas.bi.appDb.appDbCreatorConnString }}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.whDbCreatorConnString" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.whDbCreatorConnString -}}
		{{ .Values.global.dundas.bi.appDb.whDbCreatorConnString }}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.useExistingSecretForAppDbCreatorConnectionString" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.useExistingSecretForAppDbCreatorConnectionString -}}
		{{ .Values.global.dundas.bi.appDb.useExistingSecretForAppDbCreatorConnectionString }}
		{{- else -}}
		{{ false }}
		{{- end -}}
      {{- else -}}
      {{ false }}
      {{- end -}}
    {{- else -}}
	{{ false }}
    {{- end -}}
  {{- else -}}
  {{ false }}
  {{- end -}}
{{- else -}}
{{ false }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.useExistingSecretForWhDbCreatorConnectionString" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.useExistingSecretForWhDbCreatorConnectionString -}}
		{{ .Values.global.dundas.bi.appDb.useExistingSecretForWhDbCreatorConnectionString }}
		{{- else -}}
		{{ false }}
		{{- end -}}
      {{- else -}}
      {{ false }}
      {{- end -}}
    {{- else -}}
	{{ false }}
    {{- end -}}
  {{- else -}}
  {{ false }}
  {{- end -}}
{{- else -}}
{{ false }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.secretKeyRef -}}
		  {{- if .Values.global.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName -}}
		  {{ .Values.global.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName }}
		  {{- else -}}
		  {{ "" }}
		  {{- end -}}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.secretKeyRef -}}
		  {{- if .Values.global.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey -}}
		  {{ .Values.global.dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey }}
		  {{- else -}}
		  {{ "" }}
		  {{- end -}}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretName" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.secretKeyRef -}}
		  {{- if .Values.global.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretName -}}
		  {{ .Values.global.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretName }}
		  {{- else -}}
		  {{ "" }}
		  {{- end -}}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretKey" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.secretKeyRef -}}
		  {{- if .Values.global.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretKey -}}
		  {{ .Values.global.dundas.bi.appDb.secretKeyRef.warehouseDbConnStringSecretKey }}
		  {{- else -}}
		  {{ "" }}
		  {{- end -}}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretName" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.secretKeyRef -}}
		  {{- if .Values.global.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretName -}}
		  {{ .Values.global.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretName }}
		  {{- else -}}
		  {{ "" }}
		  {{- end -}}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretKey" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.secretKeyRef -}}
		  {{- if .Values.global.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretKey -}}
		  {{ .Values.global.dundas.bi.appDb.secretKeyRef.appDbCreatorConnStringSecretKey }}
		  {{- else -}}
		  {{ "" }}
		  {{- end -}}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretName" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.secretKeyRef -}}
		  {{- if .Values.global.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretName -}}
		  {{ .Values.global.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretName }}
		  {{- else -}}
		  {{ "" }}
		  {{- end -}}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretKey" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.appDb -}}
        {{- if .Values.global.dundas.bi.appDb.secretKeyRef -}}
		  {{- if .Values.global.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretKey -}}
		  {{ .Values.global.dundas.bi.appDb.secretKeyRef.warehouseDbCreatorConnStringSecretKey }}
		  {{- else -}}
		  {{ "" }}
		  {{- end -}}
		{{- else -}}
		{{ "" }}
		{{- end -}}
      {{- else -}}
      {{ "" }}
      {{- end -}}
    {{- else -}}
	{{ "" }}
    {{- end -}}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.dundas.bi.password.useExistingSecretForAdminPassword" -}}
{{- if .Values.global -}}
  {{- if .Values.global.dundas -}}
    {{- if .Values.global.dundas.bi -}}
      {{- if .Values.global.dundas.bi.password -}}
        {{- if .Values.global.dundas.bi.password.useExistingSecretForAdminPassword -}}
		{{ .Values.global.dundas.bi.password.useExistingSecretForAdminPassword }}
		{{- else -}}
		{{ false }}
		{{- end -}}
      {{- else -}}
      {{ false }}
      {{- end -}}
    {{- else -}}
	{{ false }}
    {{- end -}}
  {{- else -}}
  {{ false }}
  {{- end -}}
{{- else -}}
{{ false }}
{{- end -}}
{{- end -}}



{{- define "dundas.bi.password.useExistingSecretForAdminPassword" -}}
{{- if ( include "global.dundas.bi.password.useExistingSecretForAdminPassword" . ) -}} 
{{ ( include "global.dundas.bi.password.useExistingSecretForAdminPassword" . ) }}
{{- else -}}
{{ .Values.dundas.bi.password.useExistingSecretForAdminPassword }}
{{- end -}}
{{- end -}}

{{- define "global.image.imagePullPolicy" -}}
{{- if .Values.global -}}
  {{- if .Values.global.image -}}
    {{- if .Values.global.image.pullPolicy -}}
	{{ .Values.global.image.pullPolicy }}
	{{- else -}}
	{{ "" }}
	{{- end -}}
  {{- else -}}
{{ "" }}  
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "imagePullPolicy" -}}
{{- if ( include "global.image.imagePullPolicy" . ) -}} 
{{ ( include "global.image.imagePullPolicy" . ) }}
{{- else if .Values.image.pullPolicy -}}
{{ .Values.image.pullPolicy }}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "global.imageRegistry" -}}
{{- if .Values.global -}}
  {{- if .Values.global.imageRegistry -}}
  {{ .Values.global.imageRegistry }}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "dundas.bi.defaultImageRepository" -}}
{{- if ( include "global.imageRegistry" . ) -}} 
{{ ( include "global.imageRegistry" . ) }}
{{- else -}}
{{ .Values.dundas.bi.defaultImageRepository }}
{{- end -}}
{{- end -}}



{{- define "global.storageClass" -}}
{{- if .Values.global -}}
  {{- if .Values.global.storageClass -}}
  {{ .Values.global.storageClass }}
  {{- else -}}
  {{ "" }}
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}

{{- define "dundas.bi.storageClassName" -}}
{{- if ( include "global.storageClass" . ) -}} 
{{ ( include "global.storageClass" . ) }}
{{- else -}}
{{ .Values.dundas.bi.storageClassName }}
{{- end -}}
{{- end -}}

{{- define "dundas.bi.imagePullSecrets" -}}
{{- if .Values.global -}}
  {{- if .Values.global.imagePullSecrets -}}

  
{{- with .Values.global.imagePullSecrets }}
imagePullSecrets:
  {{- toYaml . | nindent 8 }}
 {{- end }}
  
  {{- else -}}

{{- with .Values.imagePullSecrets }}
imagePullSecrets:
  {{- toYaml . | nindent 8 }}
{{- end -}}

  {{- end -}}
{{- else -}}
{{- with .Values.imagePullSecrets }}
imagePullSecrets:
  {{- toYaml . | nindent 8 }}
{{- end -}}
{{- end -}}
{{- end -}}

{{- define "global.logi.symphony.auth.existingSecret" -}}
{{- if .Values.global -}}
  {{- if .Values.global.logi -}}
  {{- if .Values.global.logi.symphony -}}
  
    {{- if .Values.global.logi.symphony.auth -}}
	  {{- if .Values.global.logi.symphony.auth.existingSecret -}}
	  {{ .Values.global.logi.symphony.auth.existingSecret }}
	  {{- else -}}
	  {{ "" }}
	  {{- end -}}
	{{- else -}}
	{{ "" }}
	{{- end -}}
  
  {{- else -}}
  {{ "" }}  
  {{- end -}}
  
  {{- else -}}
  {{ "" }}  
  {{- end -}}
{{- else -}}
{{ "" }}
{{- end -}}
{{- end -}}


{{- define "dundas.bi.existingSecretName" }}
  {{- $secretname := "" -}}
  {{- if ne ( include "logi.symphony.auth.existingSecret" .) ""  -}}
    {{- if .Values.dundas.bi.password.setAdminPassword -}}
      {{- $secretname = ( include "logi.symphony.auth.existingSecret" . ) -}}
    {{- end -}}
  {{- else if .Values.dundas.bi.password.useExistingSecretForAdminPassword -}}
      {{- $secretname = ( .Values.dundas.bi.password.secretKeyRef.adminPasswordSecretName ) -}}         
  {{- end -}}
  {{- $secretname -}}
{{- end }}

{{- define "dundas.bi.existingSecretKey" }}
  {{- $secretkey := "" -}}
  {{- if ne ( include "logi.symphony.auth.existingSecret" .) ""  -}}
    {{- if .Values.dundas.bi.password.setAdminPassword -}}
      {{- $secretkey = ( include "logi.symphony.auth.secretKeys.adminPasswordKey" . ) -}}
    {{- end -}}
  {{- else if .Values.dundas.bi.password.useExistingSecretForAdminPassword -}}
      {{- $secretkey = ( .Values.dundas.bi.password.secretKeyRef.adminPasswordSecretKey ) -}}             
  {{- end -}}
  {{- $secretkey -}}
{{- end }}

{{- define "dundas.bi.useSecret" }}
  {{- if ne .Values.dundas.bi.password.setAdminPassword true -}}
  {{- false -}}
  {{- else if ne ( include "logi.symphony.auth.existingSecret" .) ""  -}}
  {{- true -}}
  {{- else if .Values.dundas.bi.password.useExistingSecretForAdminPassword -}}
  {{- true -}}
  {{- else -}}
  {{- false -}}  
  {{- end -}}
{{- end }}

{{- define "logisymphonydetected" }}
  {{- if .Values.global -}}
    {{- if .Values.global.logi -}}
	  {{- if .Values.global.logi.symphony -}}
	    {{- true -}}
	  {{- else -}}
	    {{- false -}}
	  {{- end -}}
	{{- else -}}
	  {{- false -}}
	{{- end -}}
  {{- else -}}
    {{- false -}}
  {{- end -}}
{{- end }}

{{- define "logi.composer.enabled" }}
  {{- if .Values.global -}}
    {{- if .Values.global.logi -}}
      {{- if  .Values.global.logi.symphony.discovery -}}
	    {{- if .Values.global.logi.symphony.discovery -}}
	      {{- if .Values.global.logi.symphony.discovery.enabled -}}
		    {{- .Values.global.logi.symphony.discovery.enabled -}}
		  {{- else -}}
		    {{- false -}}
		  {{- end -}}
	    {{- else -}}
	      {{- false -}}
	    {{- end -}}
      {{- else -}}
        {{- false -}}
      {{- end -}}
    {{- else -}}
	  {{- false -}}
	{{- end -}}
  {{- else -}}
    {{- false -}}
  {{- end -}}
{{- end }}


{{- define "common.tplvalues.render" -}}
    {{- if typeIs "string" .value }}
        {{- tpl .value .context }}
    {{- else }}
        {{- tpl (.value | toYaml) .context }}
    {{- end }}
{{- end -}}
